@@ -56,6 +56,7 @@ from docutils.parsers.rst import roles
 from sphinx.ext.autodoc import ClassDocumenter
 
 from .. import _setup_sig, metadata
+from .example import example_func
 
 
 HERE = Path(__file__).parent.resolve()
@@ -82,6 +83,9 @@ def _init_vars(app: Sphinx, config: Config):
     config.html_static_path.append(str(HERE / "static"))
 
 
+example_func.__module__ = "scanpydoc.elegant_typehints"  # Make it show up here
+
+
 @_setup_sig
 def setup(app: Sphinx) -> Dict[str, Any]:
     """Patches :mod:`sphinx_autodoc_typehints` for a more elegant display."""
